@@ -12,7 +12,7 @@ use hvcg_iam_openapi_identity::{Api, ApiNoContext, Client, ContextWrapperExt, mo
                       UpdateUserResponse,
                       QueryUserByIdResponse,
                       QueryUsersResponse,
-                      DeleteSaintResponse,
+                      DeleteUserResponse,
                      };
 use clap::{App, Arg};
 
@@ -36,7 +36,7 @@ fn main() {
             .possible_values(&[
                 "QueryUserById",
                 "QueryUsers",
-                "DeleteSaint",
+                "DeleteUser",
             ])
             .required(true)
             .index(1))
@@ -138,8 +138,8 @@ fn main() {
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
-        Some("DeleteSaint") => {
-            let result = rt.block_on(client.delete_saint(
+        Some("DeleteUser") => {
+            let result = rt.block_on(client.delete_user(
                   serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
