@@ -103,7 +103,7 @@ use hvcg_iam_openapi_identity::{
     UpdateUserResponse,
     QueryUserByIdResponse,
     QueryUsersResponse,
-    DeleteSaintResponse,
+    DeleteUserResponse,
 };
 use hvcg_iam_openapi_identity::server::MakeService;
 use std::error::Error;
@@ -195,14 +195,14 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         Err("Generic failuare".into())
     }
 
-    /// Deletes a saint
-    async fn delete_saint(
+    /// Deletes a user
+    async fn delete_user(
         &self,
         id: uuid::Uuid,
-        context: &C) -> Result<DeleteSaintResponse, ApiError>
+        context: &C) -> Result<DeleteUserResponse, ApiError>
     {
         let context = context.clone();
-        info!("delete_saint({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
+        info!("delete_user({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
