@@ -43,7 +43,7 @@ use crate::{Api,
      UpdateUserResponse,
      QueryUserByIdResponse,
      QueryUsersResponse,
-     DeleteSaintResponse
+     DeleteUserResponse
      };
 
 /// Convert input into a base path, e.g. "http://example:123". Also checks the scheme as it goes.
@@ -910,7 +910,7 @@ impl<S, C> Api<C> for Client<S, C> where
             404 => {
                 let body = response.into_body();
                 Ok(
-                    UpdateUserResponse::SaintNotFound
+                    UpdateUserResponse::UserNotFound
                 )
             }
             405 => {
@@ -1179,10 +1179,10 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn delete_saint(
+    async fn delete_user(
         &self,
         param_id: uuid::Uuid,
-        context: &C) -> Result<DeleteSaintResponse, ApiError>
+        context: &C) -> Result<DeleteUserResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
@@ -1244,19 +1244,19 @@ impl<S, C> Api<C> for Client<S, C> where
             200 => {
                 let body = response.into_body();
                 Ok(
-                    DeleteSaintResponse::SuccessfulOperation
+                    DeleteUserResponse::SuccessfulOperation
                 )
             }
             400 => {
                 let body = response.into_body();
                 Ok(
-                    DeleteSaintResponse::InvalidIDSupplied
+                    DeleteUserResponse::InvalidIDSupplied
                 )
             }
             404 => {
                 let body = response.into_body();
                 Ok(
-                    DeleteSaintResponse::SaintNotFound
+                    DeleteUserResponse::UserNotFound
                 )
             }
             code => {
