@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.1.2";
+pub const API_VERSION: &'static str = "0.1.4";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -66,8 +66,8 @@ pub enum UpdateUserResponse {
     /// Invalid ID supplied
     InvalidIDSupplied
     ,
-    /// Saint not found
-    SaintNotFound
+    /// User not found
+    UserNotFound
     ,
     /// Validation exception
     ValidationException
@@ -103,15 +103,15 @@ pub enum QueryUsersResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum DeleteSaintResponse {
+pub enum DeleteUserResponse {
     /// successful operation
     SuccessfulOperation
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
     ,
-    /// Saint not found
-    SaintNotFound
+    /// User not found
+    UserNotFound
 }
 
 /// API
@@ -169,11 +169,11 @@ pub trait Api<C: Send + Sync> {
         count: Option<i32>,
         context: &C) -> Result<QueryUsersResponse, ApiError>;
 
-    /// Deletes a saint
-    async fn delete_saint(
+    /// Deletes a user
+    async fn delete_user(
         &self,
         id: uuid::Uuid,
-        context: &C) -> Result<DeleteSaintResponse, ApiError>;
+        context: &C) -> Result<DeleteUserResponse, ApiError>;
 
 }
 
@@ -233,11 +233,11 @@ pub trait ApiNoContext<C: Send + Sync> {
         count: Option<i32>,
         ) -> Result<QueryUsersResponse, ApiError>;
 
-    /// Deletes a saint
-    async fn delete_saint(
+    /// Deletes a user
+    async fn delete_user(
         &self,
         id: uuid::Uuid,
-        ) -> Result<DeleteSaintResponse, ApiError>;
+        ) -> Result<DeleteUserResponse, ApiError>;
 
 }
 
@@ -340,14 +340,14 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().query_users(username, phone, email, enabled, offset, count, &context).await
     }
 
-    /// Deletes a saint
-    async fn delete_saint(
+    /// Deletes a user
+    async fn delete_user(
         &self,
         id: uuid::Uuid,
-        ) -> Result<DeleteSaintResponse, ApiError>
+        ) -> Result<DeleteUserResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().delete_saint(id, &context).await
+        self.api().delete_user(id, &context).await
     }
 
 }
