@@ -29,7 +29,7 @@ use crate::{Api,
      UpdateUserResponse,
      QueryUserByIdResponse,
      QueryUsersResponse,
-     DeleteSaintResponse
+     DeleteUserResponse
 };
 
 mod paths {
@@ -644,7 +644,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(400).expect("Unable to turn 400 into a StatusCode");
                                                 },
-                                                UpdateUserResponse::SaintNotFound
+                                                UpdateUserResponse::UserNotFound
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(404).expect("Unable to turn 404 into a StatusCode");
                                                 },
@@ -913,7 +913,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
-            // DeleteSaint - DELETE /mutation-api/identity-service/users/{id}
+            // DeleteUser - DELETE /mutation-api/identity-service/users/{id}
             &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
@@ -948,7 +948,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         .expect("Unable to create Bad Request response for invalid percent decode"))
                 };
 
-                                let result = api_impl.delete_saint(
+                                let result = api_impl.delete_user(
                                             param_id,
                                         &context
                                     ).await;
@@ -960,15 +960,15 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
 
                                         match result {
                                             Ok(rsp) => match rsp {
-                                                DeleteSaintResponse::SuccessfulOperation
+                                                DeleteUserResponse::SuccessfulOperation
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
                                                 },
-                                                DeleteSaintResponse::InvalidIDSupplied
+                                                DeleteUserResponse::InvalidIDSupplied
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(400).expect("Unable to turn 400 into a StatusCode");
                                                 },
-                                                DeleteSaintResponse::SaintNotFound
+                                                DeleteUserResponse::UserNotFound
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(404).expect("Unable to turn 404 into a StatusCode");
                                                 },
@@ -1018,8 +1018,8 @@ impl<T> RequestParser<T> for ApiRequestParser {
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS_ID) => Ok("QueryUserById"),
             // QueryUsers - GET /query-api/identity-service/users
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS) => Ok("QueryUsers"),
-            // DeleteSaint - DELETE /mutation-api/identity-service/users/{id}
-            &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => Ok("DeleteSaint"),
+            // DeleteUser - DELETE /mutation-api/identity-service/users/{id}
+            &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ID) => Ok("DeleteUser"),
             _ => Err(()),
         }
     }
